@@ -1,32 +1,25 @@
-from calendar import timegm
-from collections.abc import Iterable, Mapping
-from datetime import datetime, timedelta
 import json
-from revjwt.jws import encode as jws_encode, decode as jws_decode
+from calendar import timegm
+from collections.abc import Mapping
+from datetime import datetime
+from typing import Any, Dict, List, Optional, Union
+
 from jwt.api_jwt import PyJWT
-from jwt.exceptions import (
-    DecodeError,
-    InvalidAlgorithmError,
-    InvalidSignatureError,
-    InvalidTokenError,
-    ExpiredSignatureError,
-    ImmatureSignatureError,
-    InvalidAudienceError,
-    InvalidIssuedAtError,
-    InvalidIssuerError,
-    MissingRequiredClaimError,
-)
+from jwt.exceptions import DecodeError, InvalidAudienceError, MissingRequiredClaimError
+
+from revjwt.jws import decode as jws_decode
+from revjwt.jws import encode as jws_encode
 
 
 class JWT(PyJWT):
     def encode(
         self,
-        payload,
-        key,
-        algorithm='RSA256',
-        headers=None,
-        json_encoder=None,
-    ):
+        payload: Dict[str, Any],
+        key: str,
+        algorithm: str = "RSA256",
+        headers: Optional[Dict[str, Any]] = None,
+        json_encoder: Any = None,
+    ) -> str:
         # Check that we get a mapping
         if not isinstance(payload, Mapping):
             raise TypeError(
@@ -39,8 +32,7 @@ class JWT(PyJWT):
         for time_claim in ["exp", "iat", "nbf"]:
             # Convert datetime to a intDate value in known time-format claims
             if isinstance(payload.get(time_claim), datetime):
-                payload[time_claim] = timegm(
-                    payload[time_claim].utctimetuple())
+                payload[time_claim] = timegm(payload[time_claim].utctimetuple())
 
         json_payload = json.dumps(
             payload, separators=(",", ":"), cls=json_encoder
@@ -48,15 +40,13 @@ class JWT(PyJWT):
 
         return jws_encode(json_payload, key, algorithm, headers, json_encoder)
 
-    def decode_complete(
+    def decode_complete(  # type: ignore[override]
         self,
-        jwt,
-        algorithms=None,
-        key="",
-        options=None,
-        **kwargs,
-    ):
-        algorithms = ['RS256']
+        jwt: str,
+        options: Any = None,
+        **kwargs: Any,
+    ) -> Dict[str, Any]:
+        algorithms = ["RS256"]
         if options is None:
             options = {"verify_signature": True}
         else:
@@ -69,7 +59,7 @@ class JWT(PyJWT):
 
         decoded = jws_decode(
             jwt,
-            key=key,
+            key="",
             algorithms=algorithms,
             options=options,
             **kwargs,
@@ -84,12 +74,14 @@ class JWT(PyJWT):
 
         if options["verify_signature"]:
             merged_options = {**self.options, **options}
-            self._validate_claims(payload, merged_options, **kwargs)
+            self._validate_claims(payload, merged_options, **kwargs)  # type: ignore
 
         decoded["payload"] = payload
         return decoded
 
-    def _validate_aud(self, payload, audience):
+    def _validate_aud(
+        self, payload: Dict[str, Any], audience: Union[str, List[str]]
+    ) -> None:
         if audience is None:
             return
         if audience is None and "aud" not in payload:
@@ -98,7 +90,7 @@ class JWT(PyJWT):
         if audience is not None and "aud" not in payload:
             # Application specified an audience, but it could not be
             # verified since the token does not contain a claim.
-            raise MissingRequiredClaimError("aud")
+            raise MissingRequiredClaimError("aud")  # type: ignore
 
         audience_claims = payload["aud"]
 
@@ -116,6 +108,6 @@ class JWT(PyJWT):
             raise InvalidAudienceError("Invalid audience")
 
 
-_jwt = JWT()
+_jwt = JWT()  # type: ignore
 encode = _jwt.encode
 decode = _jwt.decode
